# dt-browser

A TUI application built using [Textual](https://github.com/Textualize/textual) to browse, search, filter, and interact with dataframes visually in the terminal.

## Features

- Searching using SQL-syntax
- Filtering using SQL-syntax
- Bookmark individual rows and navigate between bookmarks
- Reorder/hide columns
- Color contiguous rows based on a user-defined set of columns

## Screenshots

### Basic View

![Basic](basic.svg?raw=true "Basic View")

### Searching

![Searching](searching.svg?raw=true "Searching")

### Filtering

![Filtering](filtering.svg?raw=true "Filtering")
